@@ -11,34 +11,13 @@ import unicodedata, unittest
 import importlib.resources as pkg_resources
 
 
-
-class MatchingType(IntFlag):
-    Abbreviation = 1 << 0
-    Additional = 1 << 1
-    Exact = 1 << 2
-    Initials = 1 << 3
-    Shorthand = 1 << 4
-    Synonym = 1 << 5
-    Translation = 1 << 6
-    Transliteration = 1 << 7
-    Typography = 1 << 8
-    NoMatch = 0
-
-
 class MatchingResult:
-    def __init__(self, score=0, kind=0):
+    def __init__(self, score=0):
         self.score = score
-        self.kind = kind
-
-    @staticmethod
-    def NoMatch():
-        return MatchingResult(0, MatchingType.NoMatch)
 
 
 class MatcherMixin:
 
-    additional_flag = MatchingType.NoMatch
-
     def match(self, lhs, rhs, original_lhs, original_rhs, **parameters):
         new_lhs, new_rhs = self.normalize(lhs, rhs, original_lhs, original_rhs, **parameters)
         return self.compare(new_lhs, new_rhs, original_lhs, original_rhs, **parameters), new_lhs, new_rhs
@@ -72,20 +51,13 @@ class TokenCategoryComparer(ComparerMixin):
 
         number_of_entity_words = len(abbreviations_lhs) + len(company_words_lhs) + len(abbreviations_rhs) + len(
                                                                                                     company_words_rhs)
-        if number_of_entity_words > parameters.get("maximal_entity_words_unmatched", 1):
-            return MatchingResult.NoMatch()
-
-        if number_of_entity_words > 0:
-            self.additional_flag = MatchingType.Additional
-
-
 
 class OtherWordsComparer(ComparerMixin):
 
     def compare(self, lhs, rhs, original_lhs, original_rhs, **parameters):
         typographies_in_raw=40
         ratio = fuzz.token_sort_ratio(str(lhs), str(rhs))
-        return MatchingResult(ratio, MatchingType.Typography)
+        return MatchingResult(ratio)
 
 
 class LevenshteinComparer(ComparerMixin):
@@ -96,9 +68,9 @@ class LevenshteinComparer(ComparerMixin):
         if edit <= parameters.get("maximal_typographies_in_raw", 1):
             ratio = self.__ratio_distance(edit, lhs, rhs)
             if edit == 0 and len(lhs) == len(rhs):
-                return MatchingResult(ratio, MatchingType.Exact)
+                return MatchingResult(ratio)
             else:
-                return MatchingResult(ratio, MatchingType.Typography)
+                return MatchingResult(ratio)
 
     def __ratio_distance(self, edit_score, lhs, rhs):
         if edit_score == 0:
@@ -108,63 +80,19 @@ class LevenshteinComparer(ComparerMixin):
             return int(((len_sum - edit_score) / len_sum) * 100)
 
 
-class InitialComparer(ComparerMixin):
-
-    def __init__(self, pipeline):
-        super()
-        self.__pipeline = pipeline
-
-
-    def compare(self, lhs, rhs, original_lhs, original_rhs, **parameters):
-        shortest, longest = lhs, rhs
-        if len(shortest) > len(longest):
-            shortest, longest = rhs, lhs
-
-        tokens_shortest = shortest.split()
-        tokens_longest = longest.split()
-
-        for short_index, token in enumerate(tokens_shortest):
-            if len(token) < parameters.get("maximal_initialism", 5) and len(token) < len(tokens_longest):
-                initial_index = 0
-                first_initial = token[initial_index]
-                for i in range(len(tokens_longest)):
-                    if tokens_longest[i][0] == first_initial:
-                        j = i + 1
-                        initial_index += 1
-                        while j != len(tokens_longest) and initial_index != len(token):
-                            if tokens_longest[j][0] == token[initial_index]:
-                                initial_index += 1
-                                j += 1
-                            else:
-                                break
-
-                        # If we have eventually a match of abbreviations
-                        if initial_index == len(token):
-                            result, _, _ = self.__pipeline.match(
-                                u''.join(tokens_shortest[short_index + 1:]),
-                                u''.join(tokens_longest[:i] + tokens_longest[i + initial_index:]),
-                                original_lhs,
-                                original_rhs,
-                                **parameters)
-                            if result.kind != MatchingType.NoMatch:
-                                result.kind |= MatchingType.Initials
-                                return result
-
-
 class ElfType(IntEnum):
     '''first column of the elf_company dataset'''
     Abbreviation = 0,
     LocalName = 1, # = company word
     TransliteratedAbbreviation = 2,
     TransliteratedLocalName = 3,
-    Unknown = 5,
+    Unknown = 5
 
 
 class Elf:
     def __init__(self):
-        content = pkg_resources.open_text('company_name_matching', 'elf_company.csv')
-        #file_path = os.path.join(os.path.dirname(__file__), 'data/elf_company.csv')
-        self.__elf_database = self.__read_from_csv(content)
+        file_path = os.path.join(os.path.dirname(__file__), 'elf_company.csv')
+        self.__elf_database = self.__read_from_csv(file_path)
 
     def get(self, elf_type, token, country='AA'):
         country_mapping = self.__elf_database[country]
@@ -173,31 +101,32 @@ class Elf:
         else:
             return country_mapping[elf_type].get(token)
 
-    def __read_from_csv(self, content):
+    def __read_from_csv(self, file_path):
         elf_database = {}
-        spamreader = csv.reader(content, delimiter=',', quotechar='"', strict=True)
-        for tokens in spamreader:
+        with open(file_path, 'r', encoding='utf-8') as csvfile:
+            spamreader = csv.reader(csvfile, delimiter=',', quotechar='"', strict=True)
+            for tokens in spamreader:
 
-            country = tokens[0]
-            elf_type = ElfType(int(tokens[1]))
-            word = tokens[2]
-            elfs = set(tokens[3].split(';'))
+                country = tokens[0]
+                elf_type = ElfType(int(tokens[1]))
+                word = tokens[2]
+                elfs = set(tokens[3].split(';'))
 
-            country_mapping = elf_database.get(country, None)
-            if country_mapping is None:
-                word_mapping = {}
-                word_mapping[word] = elfs
-                country_mapping = [None for _ in range(4)]
-                country_mapping[elf_type] = word_mapping
-            else:
-                word_mapping = country_mapping[elf_type]
-                if word_mapping is not None:
+                country_mapping = elf_database.get(country, None)
+                if country_mapping is None:
+                    word_mapping = {}
                     word_mapping[word] = elfs
+                    country_mapping = [None for _ in range(4)]
+                    country_mapping[elf_type] = word_mapping
                 else:
-                    word_mapping = { word: elfs }
-                country_mapping[elf_type] = word_mapping
+                    word_mapping = country_mapping[elf_type]
+                    if word_mapping is not None:
+                        word_mapping[word] = elfs
+                    else:
+                        word_mapping = { word: elfs }
+                    country_mapping[elf_type] = word_mapping
 
-            elf_database[country] = country_mapping
+                elf_database[country] = country_mapping
         return elf_database
 
 
@@ -237,13 +166,8 @@ class TokenCategoryNormalizer(NormalizerMixin):
             else:
                 if transliterate_function is not None:
                     transliteration = transliterate_function(token)
-                    if transliteration is None:
-                        others.append(token)
-                    else:
-                        self.additional_flag = MatchingType.Transliteration
-                        others.append(transliteration)
-                else:
-                    others.append(token)
+
+            others.append(token)
         return abbreviations, company_words, others
 
     def __categorize_token(self, token, parameters):
@@ -284,14 +208,12 @@ class TokenCategoryNormalizer(NormalizerMixin):
                 return ElfType.LocalName, local_names_elfs
 
 
-
 class StripNormalizer(NormalizerMixin):
 
     def normalize(self, lhs, rhs, original_lhs, original_rhs, **parameters):
         return lhs.strip(), rhs.strip()
 
 
-
 class SplitNormalizer(NormalizerMixin):
 
     def normalize(self, lhs, rhs, original_lhs, original_rhs, **parameters):
@@ -325,22 +247,19 @@ class OtherWordsAbbreviationNormalizer(NormalizerMixin):
             if not considered_rhs[index]:
                 others = self.abbreviations.get(l, None)
                 if others is not None:
-                    if other in lhs:
-                        pos = lhs.index(other)
-                        if pos != -1 and considered_lhs[pos] == False:
-                            considered_lhs[index] = True
-                            considered_rhs[pos] = True
-                            lhs_to_remove.add(l)
-                            rhs_to_remove.add(other)
+                    for other in others:
+                        if other in lhs:
+                            pos = lhs.index(other)
+                            if pos != -1 and considered_lhs[pos] == False:
+                                considered_lhs[index] = True
+                                considered_rhs[pos] = True
+                                lhs_to_remove.add(l)
+                                rhs_to_remove.add(other)
 
         for to_remove in lhs_to_remove:
             lhs.remove(to_remove)
         for to_remove in rhs_to_remove:
             rhs.remove(to_remove)
-
-        if original_length != len(lhs):
-            self.additional_flag |= MatchingType.Abbreviation
-
         return lhs, rhs
 
 
@@ -383,6 +302,32 @@ class KeepOtherWordsNormalizer(NormalizerMixin):
     def normalize(self, lhs, rhs, original_lhs, original_rhs, **parameters):
         normalized_lhs = lhs[2]
         normalized_rhs = rhs[2]
+        lhs_all_abrv = lhs[0].copy()
+        lhs_all_abrv.update(lhs[1])
+        rhs_all_abrv = rhs[0].copy()
+        rhs_all_abrv.update(rhs[1])
+        for elements_lhs in lhs_all_abrv.values():
+            for element_lhs in elements_lhs:
+                if element_lhs == "TY0P":
+                    lhs_remove = [k for k, v in lhs_all_abrv.items() if element_lhs in v]
+                    if len(lhs_remove) > 0:
+                        normalized_lhs.remove(lhs_remove[0])
+                for elements_rhs in rhs_all_abrv.values():
+                    if element_lhs in elements_rhs:
+                        lhs_element_lhs_to_remove = [k for k, v in lhs_all_abrv.items() if element_lhs in v]
+                        if len(lhs_element_lhs_to_remove) > 0:
+                            if lhs_element_lhs_to_remove[0] in normalized_lhs:
+                                normalized_lhs.remove(lhs_element_lhs_to_remove[0])
+                        rhs_element_lhs_to_remove = [k for k, v in rhs_all_abrv.items() if element_lhs in v]
+                        if len(rhs_element_lhs_to_remove) > 0:
+                            if rhs_element_lhs_to_remove[0] in normalized_rhs:
+                                normalized_rhs.remove(rhs_element_lhs_to_remove[0])
+        for elements_rhs in rhs_all_abrv.values():
+            for element_rhs in elements_rhs:        
+                if element_rhs == "TY0P":
+                    rhs_remove = [k for k, v in rhs_all_abrv.items() if element_rhs in v]
+                    if len(rhs_remove) > 0:
+                        normalized_rhs.remove(rhs_remove[0])
         return normalized_lhs, normalized_rhs
 
 
@@ -391,7 +336,6 @@ class CommonAbbreviationNormalizer(NormalizerMixin):
     def normalize(self, lhs, rhs, original_lhs, original_rhs, **parameters):
         abbreviations_lhs = lhs[0]
         abbreviations_rhs = rhs[0]
-
         abbreviations_lhs_to_remove = []
         abbreviations_rhs_to_remove = []
         considered = [False for _ in range(len(rhs))]
@@ -403,15 +347,10 @@ class CommonAbbreviationNormalizer(NormalizerMixin):
                         abbreviations_rhs_to_remove.append(abbreviation_rhs)
                         considered[index] = True
                         break
-
         for abbreviation_to_remove in abbreviations_lhs_to_remove:
             del abbreviations_lhs[abbreviation_to_remove]
         for abbreviation_to_remove in abbreviations_rhs_to_remove:
             del abbreviations_rhs[abbreviation_to_remove]
-
-        if len(abbreviations_lhs_to_remove) + len(abbreviations_rhs_to_remove) > 0:
-            self.additional_flag = MatchingType.Synonym
-
         return lhs, rhs
 
 
@@ -477,9 +416,6 @@ class AbbreviationLegalFormNormalizer(NormalizerMixin):
 
         remaining_length = len(abbreviations_lhs) + len(company_words_rhs) + len(abbreviations_rhs) + len(
                                                                                                     company_words_lhs)
-        if original_length != remaining_length:
-            self.additional_flag = MatchingType.Shorthand # to tell that a word has been deleted
-
         return lhs, rhs
 
     def __remove_abbreviations_of_company_words(self, abbreviations, company_words):
@@ -502,23 +438,16 @@ class AbbreviationLegalFormNormalizer(NormalizerMixin):
         return abbreviations, company_words
 
 
-
 class Pipeline:
 
     def __init__(self, steps):
         self.steps = steps
 
     def match(self, lhs, rhs, original_lhs, original_rhs, **parameters):
-        for step in self.steps:
-            step.additional_flag = MatchingType.NoMatch
-
         for i in range(len(self.steps)):
             result, lhs, rhs = self.steps[i].match(lhs, rhs, original_lhs, original_rhs, **parameters)
             if result is not None:
-                for j in range(i):
-                    result.kind |= self.steps[j].additional_flag
                 return result, lhs, rhs
-        return MatchingResult.NoMatch(), lhs, rhs
 
     def __len__(self):
         return len(self.steps)
@@ -527,7 +456,6 @@ def make_pipeline(*steps):
     return Pipeline(steps)
 
 
-
 class DefaultMatching:   
 
     def __init__(self, default_parameters=None):
@@ -539,9 +467,11 @@ class DefaultMatching:
         handle_company_words = make_pipeline(
             SplitNormalizer(), # split words
             TokenCategoryNormalizer(), # associate each word to a word from the elf dataset
-            AbbreviationLegalFormNormalizer(), CommonAbbreviationNormalizer(),
+            #AbbreviationLegalFormNormalizer(), 
+            CommonAbbreviationNormalizer(),
             TokenCategoryComparer(),
-            KeepOtherWordsNormalizer(), AndNormalizer(self.default_parameters.and_words),
+            KeepOtherWordsNormalizer(), 
+            AndNormalizer(self.default_parameters.and_words),
             OtherWordsAbbreviationNormalizer(self.default_parameters.abbreviations),
             OtherWordsComparer()
         )
@@ -550,7 +480,6 @@ class DefaultMatching:
             UnicodeNormalizer(), 
             CharacterNormalizer(self.default_parameters.meaningless_characters_without_dot), 
             MisplacedCharacterNormalizer(),
-            LevenshteinComparer(), # detect typography problems
             handle_company_words
         )
 
@@ -564,12 +493,10 @@ class DefaultMatching:
 class MatchingParameters:
     __MEANINGLESS_CHARACTERS = ['.', ',', '/', '\\', '\'', '(', ')', '’', '-']
 
-    def __init__(self, typographies_in_raw=1, typographies_in_word=1, entity_words_unmatched=2, 
-                                                                    common_words_unmatched=1, maximal_initialism=5, \
+    def __init__(self, typographies_in_raw=1, entity_words_unmatched=2, common_words_unmatched=1, maximal_initialism=5, \
                                     remove_common_abbreviations=True, meaningless_characters=__MEANINGLESS_CHARACTERS):
         self.ELF = Elf()
         self.maximal_typographies_in_raw = typographies_in_raw
-        self.maximal_typographies_in_word = typographies_in_word
         self.maximal_entity_words_unmatched = entity_words_unmatched
         self.maximal_common_words_unmatched = common_words_unmatched
         self.maximal_initialism = maximal_initialism
@@ -583,8 +510,8 @@ class MatchingParameters:
             self.meaningless_characters_without_dot = meaningless_characters
         self.transliterate = None
         self.and_words = ['and', 'und', 'et']
-        self.abbreviations = json.load(pkg_resources.open_text('company_name_matching', 'abbreviations.json'))
-        #self.abbreviations = json.load(open('data/abbreviations.json'))
+        # self.abbreviations = json.load(pkg_resources.open_text('company_name_matching', 'abbreviations.json'))
+        self.abbreviations = json.load(open('data/abbreviations.json'))
 
     @staticmethod
     def default():
